@@ -1,6 +1,4 @@
-"""
-Helpers module
-"""
+"""Helpers module"""
 from .ansible import Ansible
 from .grsatnogs import GrSatnogs
 from .satnogssetup import SatnogsSetup
