@@ -1,13 +1,14 @@
-"""
-APT helper module
-"""
+"""APT helper module"""
+import logging
+
 import apt
 import lsb_release
 
+LOGGER = logging.getLogger(__name__)
+
 
 def has_updates():
-    """
-    Check for package upgrades
+    """Check for package upgrades
 
     :return: Whether package upgrades are available
     :rtype: bool
@@ -17,6 +18,8 @@ def has_updates():
         cache.update()
     except apt.cache.FetchFailedException:
         pass
+    except apt.cache.LockFailedException:
+        LOGGER.exception('Could not lock APT cache')
     cache.open(None)
     cache.upgrade(dist_upgrade=True)
     if cache.get_changes():
@@ -25,8 +28,7 @@ def has_updates():
 
 
 def get_distro():
-    """
-    Get distribution information from lsb_release
+    """Get distribution information from lsb_release
 
     :return: Distribution information
     :rtype: dict
